==> lens-6.2.5.tar.gz: lens-6.2.5/src/features/helm-charts/child-features/preferences/renderer/adding-of-custom-helm-repository/helm-file-input/helm-file-input.tsx <==
/**
 * Copyright (c) OpenLens Authors. All rights reserved.
 * Licensed under MIT License. See LICENSE in root directory for more information.
 */
import type { InputValidator } from "../../../../../../../renderer/components/input";
import { Input } from "../../../../../../../renderer/components/input";
import { Icon } from "../../../../../../../renderer/components/icon";
import { withInjectables } from "@ogre-tools/injectable-react";
import React from "react";
import getFilePathsInjectable from "./get-file-paths.injectable";
import type { FileFilter } from "electron";
import isPathInjectable from "../../../../../../../renderer/components/input/validators/is-path.injectable";

interface HelmFileInputProps {
  placeholder: string;
  fileExtensions: string[];
  value: string;
  setValue: (value: string) => void;
  "data-testid"?: string;
}

interface Dependencies {
  getFilePaths: (fileFilter: FileFilter) => Promise<{ canceled: boolean; filePaths: string[] }>;
  isPath: InputValidator<true>;
}

const NonInjectedHelmFileInput = ({
  placeholder,
  value,
  setValue,
  fileExtensions,
  getFilePaths,
  isPath,
  "data-testid": testId,
}: Dependencies & HelmFileInputProps) => (
  <div className="flex gaps align-center">
    <Input
      placeholder={placeholder}
      validators={isPath}
      className="box grow"
      value={value}
      onChange={(v) => setValue(v)}
      data-testid={testId}
    />
    <Icon
      material="folder"

      onClick={async () => {
        const { canceled, filePaths } = await getFilePaths({
          name: placeholder,
          extensions: fileExtensions,
        });

        if (!canceled && filePaths.length) {
          setValue(filePaths[0]);
        }
      }}

      tooltip="Browse"
    />
  </div>
);

export const HelmFileInput = withInjectables<Dependencies, HelmFileInputProps>(
  NonInjectedHelmFileInput,

  {
    getProps: (di, props) => ({
      getFilePaths: di.inject(getFilePathsInjectable),
      isPath: di.inject(isPathInjectable),
      ...props,
    }),
  },
);

==> lens-6.3.0.tar.gz: lens-6.3.0/src/features/helm-charts/child-features/preferences/renderer/adding-of-custom-helm-repository/helm-file-input/helm-file-input.tsx <==
/**
 * Copyright (c) OpenLens Authors. All rights reserved.
 * Licensed under MIT License. See LICENSE in root directory for more information.
 */
import type { InputValidator } from "../../../../../../../renderer/components/input";
import { Input } from "../../../../../../../renderer/components/input";
import { Icon } from "../../../../../../../renderer/components/icon";
import { withInjectables } from "@ogre-tools/injectable-react";
import React from "react";
import type { RequestFilePaths } from "./get-file-paths.injectable";
import requestFilePathsInjectable from "./get-file-paths.injectable";
import isPathInjectable from "../../../../../../../renderer/components/input/validators/is-path.injectable";

interface HelmFileInputProps {
  placeholder: string;
  fileExtensions: string[];
  value: string;
  setValue: (value: string) => void;
  "data-testid"?: string;
}

interface Dependencies {
  requestFilePaths: RequestFilePaths;
  isPath: InputValidator<true>;
}

const NonInjectedHelmFileInput = ({
  placeholder,
  value,
  setValue,
  fileExtensions,
  requestFilePaths,
  isPath,
  "data-testid": testId,
}: Dependencies & HelmFileInputProps) => (
  <div className="flex gaps align-center">
    <Input
      placeholder={placeholder}
      validators={isPath}
      className="box grow"
      value={value}
      onChange={(v) => setValue(v)}
      data-testid={testId}
    />
    <Icon
      material="folder"
      onClick={() => void requestFilePaths({
        filter: {
          name: placeholder,
          extensions: fileExtensions,
        },
        onPick: (filePaths) => {
          if (filePaths.length) {
            setValue(filePaths[0]);
          }
        },
      })}
      tooltip="Browse"
    />
  </div>
);

export const HelmFileInput = withInjectables<Dependencies, HelmFileInputProps>(NonInjectedHelmFileInput, {
  getProps: (di, props) => ({
    ...props,
    requestFilePaths: di.inject(requestFilePathsInjectable),
    isPath: di.inject(isPathInjectable),
  }),
});
